Bootstrap Components › Alert — Stisla

# Alert

## Alerts

Provide contextual feedback messages for typical user actions with the handful of available and flexible alert messages.

#### Default

This is a primary alert.
This is a secondary alert.
This is a success alert.
This is a danger alert.
This is a warning alert.
This is a info alert.
This is a light alert.
This is a dark alert.

#### Icon

Primary
This is a primary alert.
Secondary
This is a secondary alert.
Success
This is a success alert.
Danger
This is a danger alert.
Warning
This is a warning alert.
Info
This is a info alert.
Light
This is a light alert.
Dark
This is a dark alert.

#### Title

Primary
This is a primary alert.
Secondary
This is a secondary alert.
Success
This is a success alert.
Danger
This is a danger alert.
Warning
This is a warning alert.
Info
This is a info alert.
Light
This is a light alert.
Dark
This is a dark alert.

#### Dismissable

This is a primary alert.
This is a secondary alert.
This is a success alert.
This is a danger alert.
This is a warning alert.
This is a info alert.
This is a light alert.
This is a dark alert.